@@ -1,7 +1,7 @@
-import sys, json, shutil, tempfile, pprint, optparse, inspect
+import json, shutil, tempfile, pprint, optparse, inspect
 import tools
 from datetime import datetime
-from util import log
+from util import log, exit_msg, CmdError
 from git import git_clone, git_log, git_checkout
 
 def load_cmds(m):
@@ -10,9 +10,6 @@ def load_cmds(m):
             issubclass(cls, tools.Cmd)
             and cls is not tools.Cmd]
 
-
-
-
 def setupCmdLine(cmds):
     parser = optparse.OptionParser()
     parser.add_option("--in", action="append", type="str",
@@ -25,10 +22,13 @@ def setupCmdLine(cmds):
     parser.add_option("--debug", action="store_true", help="Debug commands")
     cmdgroup = optparse.OptionGroup(parser, "Commands", "Command codes")
     for c in cmds:
-        opt = c.primary_opt()
-        opt.kwargs["default"] = None
-        opt.kwargs["dest"] = c.name
-        cmdgroup.add_option("--%s" % c.name, *opt.args, **opt.kwargs)
+        options = c.options()
+        options[0].kwargs["default"] = None
+        options[0].kwargs["dest"] = c.name
+        options[0].kwargs["help"] = c.__doc__
+        cmdgroup.add_option("--%s" % c.name, *options[0].args, **options[0].kwargs)
+        for opt in options[1:]:
+            cmdgroup.add_option("--%s-%s" % (c.name, opt.name), *opt.args, **opt.kwargs)
     parser.add_option_group(cmdgroup)
     return parser
 
@@ -37,17 +37,14 @@ def main():
     parser = setupCmdLine(cmds)
     opts, args = parser.parse_args()
     try: git_repo = args[0]
-    except:
-        parser.print_usage()
-        sys.exit(1)
+    except: exit_msg(parser.get_usage())
 
     runlist = [cmd(primary_opt, debug=opts.debug)
                for cmd, primary_opt in zip(cmds, map(lambda x: getattr(opts, x.name, None), cmds))
                if primary_opt]
 
-    if len(runlist) == 0:
-        print "Must specify a command to be run"
-        sys.exit(0)
+    if len(runlist) == 0: exit_msg("Must specify a command to be run")
+
     out = {}
     for in_path in opts.in_paths:
         d = json.load(open(in_path, "r"))
@@ -83,18 +80,16 @@ def main():
             for cmd in schedule:
                 rec["results"][cmd.name] = {}
                 try: rec["results"][cmd.name] = cmd.run(git_new)
-                except tools.CmdError,e:
+                except CmdError,e:
                     log("Command '%r' failed with %d", e.cmd, e.ret)
                     log("Output: %s", e.out)
-                except Exception, e:
-                    log("Failed to get output of command: %r",e)
+               # except Exception, e:
+               #     log("Failed to get output of command: %r",e)
                 log("[%s] %s", cmd.name, pprint.pformat(rec["results"][cmd.name]))
             out[sha1] = rec
 
         log("Writing output file: %s", opts.out_path)
         json.dump(out, open(opts.out_path, "w"), indent=1)
-    except CmdError, e:
-        print "Command '%r' failed with %d" % (e.cmd, e.ret)
     finally:
         log("Tidying temp dir: %s", git_new)
         shutil.rmtree(git_new)
